pub struct ResolvedSpec {
pub ram_mb: u64,
pub cpu_cores: usize,
}Expand description
Resolved machine parameters ready to be consumed by database backends. Database tuning is computed directly from these two values.
Fields
ram_mb: u64cpu_cores: usizeAuto Trait Implementations
impl Freeze for ResolvedSpec
impl RefUnwindSafe for ResolvedSpec
impl Send for ResolvedSpec
impl Sync for ResolvedSpec
impl Unpin for ResolvedSpec
impl UnsafeUnpin for ResolvedSpec
impl UnwindSafe for ResolvedSpec